Package: NSTempRFA
Title: Adapts the Regional Frequency Analysis to Air Temperature
Version: 0.2.0
Authors@R: c(
    person("Gabriel Constantino", "Blain", , "gabriel.blain@sp.gov.br", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-8832-7734")),
    person("Graciela R.", "Sobierajski", role = "aut",
           comment = c(ORCID = "0000-0002-7211-9268")),
    person("Leticia L.", "Martins", role = "aut",
           comment = c(ORCID = "0000-0002-0299-3005")),
    person("Adam H.", "Sparks", , "adamhsparks@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0002-0061-8359"))
  )
Description: Adapts the index-flood technique to extreme air temperature
    data. The package uses the additive approach proposed in Martins et
    al. (2022) <doi:10.1590/1678-4499.20220061> and adapt it to climate
    change conditions through the use of nonstationary parametric
    distributions.
License: MIT + file LICENSE
URL: https://github.com/gabrielblain/NSTempRFA
BugReports: https://github.com/gabrielblain/NSTempRFA/issues
Depends: R (>= 3.5)
Imports: extRemes, ismev, lmom, lmomRFA, MASS, Matrix, rrcov, spsUtil,
        stats, utils
Suggests: knitr, rmarkdown, spelling, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
Config/testthat/edition: 3
Config/testthat/parallel: true
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-07-28 11:05:50 UTC; gabrielblain
Author: Gabriel Constantino Blain [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-8832-7734>),
  Graciela R. Sobierajski [aut] (ORCID:
    <https://orcid.org/0000-0002-7211-9268>),
  Leticia L. Martins [aut] (ORCID:
    <https://orcid.org/0000-0002-0299-3005>),
  Adam H. Sparks [aut] (ORCID: <https://orcid.org/0000-0002-0061-8359>)
Maintainer: Gabriel Constantino Blain <gabriel.blain@sp.gov.br>
Repository: CRAN
Date/Publication: 2026-08-06 12:50:06 UTC
