# Generated by roxygen2: do not edit by hand

export(Add_Discord)
export(Add_Heterogeneity)
export(Add_RegProb)
export(Add_RegQuant)
export(Best_model)
export(Dataset_add)
export(Fit_model)
export(Reg_par)
export(Reg_parCI)
export(Site_parCI)
importFrom(MASS,mvrnorm)
importFrom(Matrix,nearPD)
importFrom(extRemes,pevd)
importFrom(extRemes,qevd)
importFrom(ismev,gev.fit)
importFrom(lmom,pelkap)
importFrom(lmom,pelwak)
importFrom(lmom,quakap)
importFrom(lmom,quawak)
importFrom(lmomRFA,regsamlmu)
importFrom(rrcov,Cov)
importFrom(rrcov,getDistance)
importFrom(spsUtil,quiet)
importFrom(stats,na.omit)
importFrom(stats,pnorm)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,weighted.mean)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
