#' Extreme air temperature data
#'
#' Daily extremes for air temperature data sampled from
#' the block maxima approach. A block corresponds to one year.
#' The data belongs to The Climate Prediction Center - NOAA.
#' location of Ribeirao Preto, State of Sao Paulo in Brazil.
#'
#' @format ## `TmaxCPC_SP`
#' A data.frame with 11 columns and 34 rows.
#'
#' \describe{
#' \item{Year}{Year}
#' \item{Pixel_1 to Pixel_10}{daily extremes for air temperature}
#' }
#' @source <https://psl.noaa.gov/>
"TmaxCPC_SP"
