#' Geographical coordinates of the `TmaxCPC_SP` series
#'
#'
#' @format ## `lonlat_Tmax`
#' A data.frame with 2 columns and 10 rows.
#'
#' \describe{
#' \item{lon}{Longitude in decinal degrees}
#' \item{lat}{Latitude in decinal degrees}
#' }
#' @source <https://psl.noaa.gov/>
"lonlat_Tmax"
