% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reg_par.R
\name{Reg_par}
\alias{Reg_par}
\title{Estimate the parameters of the regional distribution}
\usage{
Reg_par(best_model)
}
\arguments{
\item{best_model}{A 6-column \code{data.frame} as generated by \code{Best_model()}.
\itemize{
\item Columns 1--5: \code{mu0}, \code{mu1}, \code{sigma0},
\code{sigma1}, \code{shape}.
\item Column 6: \code{size} (sample size per site, used as weight).
}}
}
\value{
A one-row \code{data.frame} with the size-weighted regional parameters of a
time-varying generalized extreme value distribution.
}
\description{
Estimate the parameters of the regional distribution
}
\examples{
add.data <- Dataset_add(TmaxCPC_SP)
best.parms <- Best_model(add.data = add.data$add_data)
Reg_par(best_model = best.parms$atsite.models)
}
