% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Add_Discord.R
\name{Add_Discord}
\alias{Add_Discord}
\title{Discordance measures calculated from the additive approach}
\usage{
Add_Discord(dataset)
}
\arguments{
\item{dataset}{A numeric matrix with extreme air temperature data from multiple sites.
The first column must contain the years, and the remaining columns contain
temperature data from each site.}
}
\value{
A \code{data.frame} with 8 columns:
\describe{
\item{Local}{Site identifier.}
\item{SampleSize}{Number of observations for each site.}
\item{l_1}{First L-moment (mean).}
\item{l_2}{Second L-moment (L-scale).}
\item{t_3}{L-skewness ratio.}
\item{t_4}{L-kurtosis ratio.}
\item{t_5}{Fifth-order L-moment ratio.}
\item{discord}{Original discordance statistic indicating potential outlier status.}
}
}
\description{
This function calculates the Hosking and Wallis' discordance measure (discord) and
the robust discordance measure (Neykov et al. 2007) \url{doi:10.1029/2006WR005322} using
the additive approach proposed in Martins et al. (2022) \url{doi:10.1590/1678-4499.20220061}.
}
\details{
The discordance measures identify sites that are potentially discordant
within a regional frequency analysis framework for extreme air temperature series.
}
\examples{
Add_Discord(TmaxCPC_SP)
}
